@@ -16,15 +16,8 @@
 from .check_error import CheckError
 from .distribution import Distribution
 from .http_request import HttpRequest
-from .log_entry import (
-    LogEntry,
-    LogEntryOperation,
-    LogEntrySourceLocation,
-)
-from .metric_value import (
-    MetricValue,
-    MetricValueSet,
-)
+from .log_entry import LogEntry, LogEntryOperation, LogEntrySourceLocation
+from .metric_value import MetricValue, MetricValueSet
 from .operation import Operation
 from .quota_controller import (
     AllocateQuotaRequest,
